@@ -2,7 +2,7 @@ from faker import Faker
 from settings import settings
 from tests import random_seed
 
-from office365.directory import UserProfile
+from office365.directory.userProfile import UserProfile
 from office365.graph_client import GraphClient
 
 
@@ -36,7 +36,7 @@ def generate_user_profile():
     return UserProfile(**user_json)
 
 
-client = GraphClient(settings['tenant'], acquire_token)
+client = GraphClient(acquire_token)
 
 for idx in range(0, 5):
     user_profile = generate_user_profile()
