@@ -1,15 +1,17 @@
 import os
 import tempfile
 
+import adal
 from settings import settings
 
-from office365.graph.graph_client import GraphClient
+from office365.graph_client import GraphClient
 
 
-def get_token(auth_ctx):
+def get_token():
     """Acquire token via client credential flow (ADAL Python library is utilized)
-    :type auth_ctx: adal.AuthenticationContext
     """
+    authority_url = 'https://login.microsoftonline.com/{0}'.format(settings['tenant'])
+    auth_ctx = adal.AuthenticationContext(authority_url)
     token = auth_ctx.acquire_token_with_client_credentials(
         "https://graph.microsoft.com",
         settings['client_credentials']['client_id'],
@@ -18,9 +20,12 @@ def get_token(auth_ctx):
 
 
 def download_files(remote_folder, local_path):
-    drive_items = remote_folder.children
-    client.load(drive_items)
-    client.execute_query()
+    """
+
+    :type remote_folder: office365.onedrive.driveItem.DriveItem
+    :type local_path: str
+    """
+    drive_items = remote_folder.children.get().execute_query()
     for drive_item in drive_items:
         if not drive_item.file.is_server_object_null:  # is file?
             # download file content
@@ -30,16 +35,15 @@ def download_files(remote_folder, local_path):
             print("File '{0}' has been downloaded".format(local_file.name))
 
 
-# example demonstrates how to export OneDrive files into local file system
+# --------------------------------------------------------------------------
+# Example demonstrates how to export OneDrive files into local file system
+# --------------------------------------------------------------------------
 
 # connect
-client = GraphClient(settings['tenant'], get_token)
+client = GraphClient(get_token)
 
 # load drive properties
 drive = client.users["jdoe@mediadev8.onmicrosoft.com"].drive
-client.load(drive)
-client.execute_query()
-
 # download files from OneDrive
 with tempfile.TemporaryDirectory() as path:
     download_files(drive.root, path)
