@@ -1,16 +1,17 @@
 import os
 from os.path import isfile, join
 
+import adal
 from settings import settings
 
 from office365.graph_client import GraphClient
 
 
-def get_token(auth_ctx):
+def get_token():
     """Acquire token via client credential flow
-
-    :type auth_ctx: adal.AuthenticationContext
     """
+    authority_url = 'https://login.microsoftonline.com/{0}'.format(settings['tenant'])
+    auth_ctx = adal.AuthenticationContext(authority_url)
     token = auth_ctx.acquire_token_with_client_credentials(
         "https://graph.microsoft.com",
         settings['client_credentials']['client_id'],
@@ -35,7 +36,7 @@ def upload_files(remote_drive, local_root_path):
 
 
 # get target drive
-client = GraphClient(settings['tenant'], get_token)
+client = GraphClient(get_token)
 target_drive = client.users["jdoe@mediadev8.onmicrosoft.com"].drive
 # import local files into OneDrive
 upload_files(target_drive, "../data")
