@@ -1,14 +1,15 @@
+import adal
 from settings import settings
 
 from office365.graph_client import GraphClient
 
 
-def get_token_for_user(auth_ctx):
+def get_token_for_user():
     """
     Acquire token via user credentials
-
-    :type auth_ctx: adal.AuthenticationContext
     """
+    authority_url = 'https://login.microsoftonline.com/{0}'.format(settings['tenant'])
+    auth_ctx = adal.AuthenticationContext(authority_url)
     token = auth_ctx.acquire_token_with_username_password(
         'https://graph.microsoft.com',
         settings['user_credentials']['username'],
@@ -28,6 +29,6 @@ def enum_folders_and_files(root_folder):
             enum_folders_and_files(drive_item)
 
 
-client = GraphClient(settings['tenant'], get_token_for_user)
+client = GraphClient(get_token_for_user)
 root = client.me.drive.root
 enum_folders_and_files(root)
