@@ -1,10 +1,13 @@
+import adal
 from settings import settings
 
-from office365.graph.graph_client import GraphClient
+from office365.graph_client import GraphClient
 
 
-def get_token(auth_ctx):
+def get_token():
     """Acquire token via client credential flow (ADAL Python library is utilized)"""
+    authority_url = 'https://login.microsoftonline.com/{0}'.format(settings['tenant'])
+    auth_ctx = adal.AuthenticationContext(authority_url)
     token = auth_ctx.acquire_token_with_client_credentials(
         "https://graph.microsoft.com",
         settings['client_credentials']['client_id'],
@@ -12,7 +15,7 @@ def get_token(auth_ctx):
     return token
 
 
-client = GraphClient(settings['tenant'], get_token)
+client = GraphClient(get_token)
 message_json = {
     "Message": {
         "Subject": "Meet for lunch?",
