@@ -4,8 +4,8 @@ from office365.runtime.auth.user_credential import UserCredential
 from office365.sharepoint.client_context import ClientContext
 
 ctx = ClientContext(settings["url"]).with_credentials(
-                                             UserCredential(settings['user_credentials']['username'],
-                                                            settings['user_credentials']['password']))
+                                             UserCredential(settings.get('user_credentials').get('username'),
+                                                            settings.get('user_credentials').get('password')))
 
 web = ctx.web
 ctx.load(web)
