@@ -6,22 +6,28 @@ from office365.runtime.types.EventHandler import EventHandler
 
 class ClientObjectCollection(ClientObject):
 
-    def __init__(self, context, item_type, resource_path=None):
+    def __init__(self, context, child_item_type, resource_path=None):
         """Client object collection
 
         :type context: office365.runtime.client_runtime_context.ClientRuntimeContext
-        :type item_type: type[ClientObject]
-        :type resource_path: ResourcePath
+        :type child_item_type: type[ClientObject]
+        :type resource_path: office365.runtime.resource_path.ResourcePath
         """
         super(ClientObjectCollection, self).__init__(context, resource_path)
         self._data = []
-        self._item_type = item_type
+        self._item_type = child_item_type
         self.page_loaded = EventHandler(False)
         self._default_page_size = 100
         self._paged_mode = True
         self._page_index = 0
         self.next_request_url = None
 
+    def get(self):
+        """
+        :rtype: ClientObjectCollection
+        """
+        return super(ClientObjectCollection, self).get()
+
     def clear(self):
         self._data = []
 
@@ -67,7 +73,11 @@ class ClientObjectCollection(ClientObject):
         return len(self._data)
 
     def __getitem__(self, index):
-        # fetch only as much items as necessary
+        """
+
+        :type index: int
+        :rtype: ClientObject
+        """
         item_iterator = iter(self)
         while len(self._data) <= index:
             next(item_iterator)
@@ -83,6 +93,11 @@ class ClientObjectCollection(ClientObject):
         return self
 
     def order_by(self, value):
+        """
+        Sets OData $orderBy query option
+
+        :type value: int
+        """
         self.query_options.orderBy = value
         return self
 
@@ -96,6 +111,9 @@ class ClientObjectCollection(ClientObject):
         return self
 
     def top(self, value):
+        """
+        :type value: int
+        """
         self._paged_mode = False
         self.query_options.top = value
         return self
@@ -110,6 +128,7 @@ class ClientObjectCollection(ClientObject):
         def _calc_items_count(resp):
             list(iter(self))
             result.value = len(self)
+
         self.context.load(self)
         self.context.after_execute(_calc_items_count)
         return result
@@ -119,7 +138,7 @@ class ClientObjectCollection(ClientObject):
         response = self.context.execute_request_direct(request)
         json = response.json()
         self.next_request_url = None
-        self.context.get_pending_request().map_json(json, self)
+        self.context.pending_request().map_json(json, self)
 
     def _get_next_items(self):
         self._page_index += 1
