@@ -1,7 +1,7 @@
-from office365.runtime.client_query import DeleteEntityQuery
 from office365.runtime.client_result import ClientResult
 from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.http.request_options import RequestOptions
+from office365.runtime.queries.delete_entity_query import DeleteEntityQuery
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
 from office365.runtime.resource_path import ResourcePath
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
@@ -33,6 +33,7 @@ class AbstractFile(BaseEntity):
         """Deletes the file."""
         qry = DeleteEntityQuery(self)
         self.context.add_query(qry)
+        return self
 
 
 class File(AbstractFile):
@@ -52,6 +53,14 @@ class File(AbstractFile):
         file = ctx.web.get_file_by_server_relative_url(file_relative_url)
         return file
 
+    def recycle(self):
+        """Moves the file to the Recycle Bin and returns the identifier of the new Recycle Bin item."""
+
+        result = ClientResult(None)
+        qry = ServiceOperationQuery(self, "Recycle", None, None, None, result)
+        self.context.add_query(qry)
+        return result
+
     def approve(self, comment):
         """Approves the file submitted for content approval with the specified comment.
 
@@ -90,6 +99,7 @@ class File(AbstractFile):
                                     },
                                     None)
         self.context.add_query(qry)
+        return self
 
     def moveto(self, new_relative_url, flag):
         """Moves the file to the specified destination URL.
@@ -105,6 +115,7 @@ class File(AbstractFile):
                                     },
                                     None)
         self.context.add_query(qry)
+        return self
 
     def publish(self, comment):
         """Submits the file for content approval with the specified comment.
@@ -163,13 +174,6 @@ class File(AbstractFile):
                                     )
         self.context.add_query(qry)
 
-    def recycle(self):
-        """Moves the file to the Recycle Bin and returns the identifier of the new Recycle Bin item."""
-        qry = ServiceOperationQuery(self,
-                                    "recycle"
-                                    )
-        self.context.add_query(qry)
-
     def get_limited_webpart_manager(self, scope):
         """Specifies the control set used to access, modify, or add Web Parts associated with this Web Part Page and
         view. """
@@ -251,7 +255,7 @@ class File(AbstractFile):
         :type content: str
         """
         url = r"{0}web/getFileByServerRelativeUrl('{1}')/\$value".format(
-            ctx.service_root_url, server_relative_url)
+            ctx.service_root_url(), server_relative_url)
         request = RequestOptions(url)
         request.method = HttpMethod.Post
         request.set_header('X-HTTP-Method', 'PUT')
@@ -268,7 +272,7 @@ class File(AbstractFile):
         :type server_relative_url: str
         :return Response
         """
-        url = r"{0}web/getfilebyserverrelativeurl('{1}')/\$value".format(ctx.service_root_url, server_relative_url)
+        url = r"{0}web/getfilebyserverrelativeurl('{1}')/\$value".format(ctx.service_root_url(), server_relative_url)
         request = RequestOptions(url)
         request.method = HttpMethod.Get
         response = ctx.execute_request_direct(request)
