@@ -1,58 +1,50 @@
-from functools import partial
-from office365.runtime.client_query import UpdateEntityQuery, DeleteEntityQuery, CreateEntityQuery
+from office365.runtime.client_result import ClientResult
+from office365.runtime.queries.create_entity_query import CreateEntityQuery
+from office365.runtime.queries.delete_entity_query import DeleteEntityQuery
+from office365.runtime.queries.service_operation_query import ServiceOperationQuery
+from office365.runtime.queries.update_entity_query import UpdateEntityQuery
 from office365.runtime.resource_path import ResourcePath
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
 from office365.sharepoint.base_entity import BaseEntity
+from office365.sharepoint.changes.change_collection import ChangeCollection
 from office365.sharepoint.files.file_creation_information import FileCreationInformation
 from office365.sharepoint.listitems.listitem import ListItem
 
 
-def _copy_files(new_folder_relative_url, overwrite, folder):
-    """Copies files
-
-    :type new_folder_relative_url: str
-    :type overwrite: bool
-    :type folder: Folder
-    """
-    for file in folder.files:
-        new_file_url = "/".join([new_folder_relative_url, file.properties['Name']])
-        file.copyto(new_file_url, overwrite)
-
-
-def _move_folder_with_files(new_folder_relative_url, flag, folder):
-    """Moves folder with files
-
-    :type new_folder_relative_url: str
-    :type flag: int
-    :type folder: Folder
-    """
-    for file in folder.files:
-        new_file_url = "/".join([new_folder_relative_url, file.properties['Name']])
-        file.moveto(new_file_url, flag)
-
-
-def _add_sub_folder(new_folder_name, target_folder, parent_folder):
-    """Creates sub folder by name
-
-    :type new_folder_name: str
-    :type parent_folder: Folder
-    """
-    new_folder_url = "/".join([parent_folder.properties['ServerRelativeUrl'], new_folder_name])
-    target_folder.set_property("ServerRelativeUrl", new_folder_url)
-    qry = CreateEntityQuery(parent_folder.folders, target_folder, target_folder)
-    parent_folder.context.add_query(qry)
-
-
 class Folder(BaseEntity):
     """Represents a folder in a SharePoint Web site."""
 
+    def recycle(self):
+        """Moves the folder to the Recycle Bin and returns the identifier of the new Recycle Bin item."""
+
+        result = ClientResult(None)
+        qry = ServiceOperationQuery(self, "Recycle", None, None, None, result)
+        self.context.add_query(qry)
+        return result
+
+    def get_list_item_changes(self, query):
+        """
+
+        :param office365.sharepoint.changeQuery.ChangeQuery query: Specifies which changes to return
+        """
+        changes = ChangeCollection(self.context)
+        qry = ServiceOperationQuery(self, "getListItemChanges", None, query, "query", changes)
+        self.context.add_query(qry)
+        return changes
+
     def add(self, name):
         """Adds the folder that is located under a current folder
 
         :type name: str
         """
         new_folder = Folder(self.context)
-        self.ensure_property("ServerRelativeUrl", partial(_add_sub_folder, name, new_folder))
+
+        def _add_sub_folder():
+            new_folder_url = "/".join([self.serverRelativeUrl, name])
+            new_folder.set_property("ServerRelativeUrl", new_folder_url)
+            qry = CreateEntityQuery(self.folders, new_folder, new_folder)
+            self.context.add_query(qry)
+        self.ensure_property("ServerRelativeUrl", _add_sub_folder)
         return new_folder
 
     def rename(self, name):
@@ -65,12 +57,14 @@ class Folder(BaseEntity):
         item.set_property('FileLeafRef', name)
         qry = UpdateEntityQuery(item)
         self.context.add_query(qry)
+        return self
 
     def delete_object(self):
         """Deletes the folder."""
         qry = DeleteEntityQuery(self)
         self.context.add_query(qry)
         self.remove_from_parent_collection()
+        return self
 
     def upload_file(self, name, content):
         """Uploads a file into folder
@@ -91,7 +85,14 @@ class Folder(BaseEntity):
         :type new_relative_url: str
         :type overwrite: bool
         """
-        self.ensure_property("Files", partial(_copy_files, new_relative_url, overwrite))
+
+        def _copy_files():
+            for file in self.files:
+                new_file_url = "/".join([new_relative_url, file.properties['Name']])
+                file.copyto(new_file_url, overwrite)
+
+        self.ensure_property("Files", _copy_files)
+        return self
 
     def moveto(self, new_relative_url, flags):
         """Moves the folder with files to the destination URL.
@@ -101,7 +102,14 @@ class Folder(BaseEntity):
         """
         if flags:
             pass
-        self.ensure_property("Files", partial(_move_folder_with_files, new_relative_url, flags))
+
+        def _move_folder_with_files():
+            """Moves folder with files"""
+            for file in self.files:
+                new_file_url = "/".join([new_relative_url, file.properties['Name']])
+                file.moveto(new_file_url, flags)
+        self.ensure_property("Files", _move_folder_with_files)
+        return self
 
     @property
     def list_item_all_fields(self):
@@ -120,6 +128,13 @@ class Folder(BaseEntity):
             from office365.sharepoint.files.file_collection import FileCollection
             return FileCollection(self.context, ResourcePath("Files", self.resource_path))
 
+    @property
+    def serverRelativeUrl(self):
+        """Gets the server-relative URL of the list folder.
+        :rtype: str or None
+        """
+        return self.properties.get("ServerRelativeUrl", None)
+
     @property
     def folders(self):
         """Get a folder collection"""
@@ -138,3 +153,4 @@ class Folder(BaseEntity):
                                                                    ResourcePath("Web"))
             elif name == "UniqueId":
                 self._resource_path = ResourcePathServiceOperation("getFolderById", [value], ResourcePath("Web"))
+        return self
