@@ -9,6 +9,12 @@ class FolderCollection(ClientObjectCollection):
     def __init__(self, context, resource_path=None):
         super(FolderCollection, self).__init__(context, Folder, resource_path)
 
+    def get(self):
+        """
+        :rtype: FolderCollection
+        """
+        return super(FolderCollection, self).get()
+
     def add(self, server_relative_url):
         """Adds the folder that is located at the specified URL to the collection.
 
